#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/install.sh - minidlna installation
#
# Creation   : 2010-01-02 jk
# Last update: $Id: install.sh 3266 2024-04-17 19:01:35Z root $
#
# Copyright (c) 2011 Peter Baeumer, <peter(at)baeumer(dot)duckdns(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set package name
packageName=minidlna

package_menu_item='MiniDLNA'
package_pos=73

# define package positions of start/stop-scripts
package_start='S'${package_pos}${packageName}
package_kill='K'`/usr/bin/expr 100 - $package_pos`${packageName}

# define config and default file
# configfile=/etc/config.d/${packageName}
# defaultfile=/etc/default.d/${packageName}

# ----------------------------------------------------------------------------
# Setup step 1
# ----------------------------------------------------------------------------

# Setup system specific values
if [ -z "${EISFAIR_SYSTEM}" ]
then
    # get eisfair system-type
    . /var/install/include/check-eisfair-version
fi

#-------------------------------------------------------------------------------
# creating symbolic links for start/stop
#-------------------------------------------------------------------------------

    # default to eisfair-1
    rm -f /etc/rc2.d/[KS]??${packageName}
    ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_kill}
    ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_start}

[ ! -d /etc/minidlna ]                  && mkdir /etc/minidlna
[ ! -d "/var/lib/${packageName}" ]      && mkdir /var/lib/${packageName}
[ -f /var/lib/minidlna/minidlna-start ] && rm /var/lib/minidlna/minidlna-start
[ -f /var/lib/minidlna/minidlna.conf ]  && rm /var/lib/minidlna/minidlna.conf
[ -f /var/lib/minidlna/minidlna.log ]   && rm /var/lib/minidlna/minidlna.log
[ -d /var/run/minidlna ]                && rm -R /var/run/minidlna

chmod 0755 /var/install/dialog.d/MINIDLNA*
chmod 0755 /etc/init.d/minidlna
touch /etc/minidlna/minidlna-start.sh
touch /etc/minidlna/minidlna.conf
chmod 0755 /etc/minidlna/minidlna-start.sh
chmod 0755 /usr/sbin/minidlnad
chmod 0775 /var/lib/minidlna

# ----------------------------------------------------------------------------
# Add menu
# ----------------------------------------------------------------------------
/var/install/bin/add-menu setup.services.menu setup.services.${packageName}.menu "${package_menu_item}"

# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------

/var/install/config.d/${packageName}-update.sh

#-----------------------------------------------------------------------------
# read configuration
#-----------------------------------------------------------------------------
. /etc/config.d/${packageName}

# ----------------------------------------------------------------------------
# Start configuration editor if necessary
# ----------------------------------------------------------------------------

[ -f /etc/config.d/${packageName} ] && /var/install/config.d/${packageName}.sh --quiet

systemctl daemon-reload

[ "${START_MINIDLNA}" = "yes" ] && /usr/sbin/service restart ${packageName}


exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
