#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/minidlna-update.sh - paramater update script
#
# Creation   : 2010-01-02 jk
# Last update: $Id: minidlna-update.sh 3266 2024-04-17 19:01:35Z root $
#
# Copyright (c) 2011 Peter Baeumer, <peter(at)baeumer(dot)duckdns(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/minidlna-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=minidlna

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_MINIDLNA='no'
MINIDLNA_PORT='8200'
MINIDLNA_USER='root'
MINIDLNA_MAX_CONNECTION='0'
MINIDLNA_NIC_N='1'
MINIDLNA_NIC_1='eth0'
MINIDLNA_MERGE_MEDIA_DIR='no'
MINIDLNA_MEDIA_N='1'
MINIDLNA_MEDIA_1_DIR='/data'
MINIDLNA_MEDIA_1_CONTENT='All'
MINIDLNA_READ_PLAYLIST='yes'
MINIDLNA_WIDE_LINKS='no'
MINIDLNA_NAME='Media'
MINIDLNA_ALBUM_NAMES='Cover.jpg/cover.jpg/Album.jpg/album.jpg/Thumb.jpg/thumb.jpg'
MINIDLNA_INOTIFY='no'
MINIDLNA_ENABLE_TIVO='no'
MINIDLNA_STRICT_DLNA='no'
MINIDLNA_WEB_URL=''
MINIDLNA_NTFY_INTERVAL='900'
MINIDLNA_SERIAL='12345678'
MINIDLNA_MODEL_NUMBER='1'
MINIDLNA_DB_DIR='/var/lib/minidlna'
MINIDLNA_ROOT_CONTAINER='use standard container'
MINIDLNA_SORT_CRITERIA='+upnp:class,+upnp:originalTrackNumber,+dc:title'
MINIDLNA_LOG_DEBUG='no'
MINIDLNA_LOG_INTERVAL='monthly'
MINIDLNA_LOG_COUNT='7'


# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
         /var/install/bin/backup-file --quiet ${packageName}
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "$(date "+%Y-%m-%d")" "Baeumer"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_MINIDLNA" "Start MINIDLNA Server? Use: yes or no"
    printvar "MINIDLNA_PORT" "port for HTTP traffic"
    printvar "MINIDLNA_MAX_CONNECTION" "maximum number of simultaneous connections"
    printvar "MINIDLNA_USER" "User to run minidlna"
    printvar "MINIDLNA_NIC_N" "number of network interface to use"
    idx=1
    while [ "$idx" -le $MINIDLNA_NIC_N ]
    do
        printvar "MINIDLNA_NIC_${idx}" "network interface to bind"
        idx=`/usr/bin/expr $idx + 1`
    done

    printvar "MINIDLNA_MERGE_MEDIA_DIR" "set this to merge all media_dir base contents into the root container"
    printvar "MINIDLNA_MEDIA_N" "Amount of Directories to scan"

    if [ $MINIDLNA_MEDIA_N -eq 0 ]
    then
        imax=1
    else
        imax=$MINIDLNA_MEDIA_N
    fi

    idx=1
    while [ "$idx" -le $imax ]
    do
        eval pDir='$MINIDLNA_MEDIA_'$idx'_DIR'
        printvar "MINIDLNA_MEDIA_${idx}_DIR" "Directory you want scan"
        printvar "MINIDLNA_MEDIA_${idx}_CONTENT" "Content of Directory"
        idx=`/usr/bin/expr $idx + 1`
    done

    printvar "MINIDLNA_READ_PLAYLIST" "do note create playlist"
    printvar "MINIDLNA_WIDE_LINKS" "set this to yes to allow symlinks that point outside user-defined media_dirs."
    printvar "MINIDLNA_NAME" "Name that shows up on your clients"
    printvar "MINIDLNA_ALBUM_NAMES" "List of file names to check for when searching for album"
    printvar "MINIDLNA_INOTIFY" "Enable monitoring to automatically discover new files? Att: Works only with kernel 2.6"
    printvar "MINIDLNA_ENABLE_TIVO" "Enable support for streaming .jpg and .mp3 files to a TiVo supporting HMO?"
    printvar "MINIDLNA_STRICT_DLNA" "Strictly adhere to DLNA standards?"
    printvar "MINIDLNA_WEB_URL" "Presentation url is http address on port 80"
    printvar "MINIDLNA_NTFY_INTERVAL" "Notify interval in seconds. Default: 895 seconds."
    printvar "MINIDLNA_SERIAL" "Serial number the daemon will report to clients in its XML description"
    printvar "MINIDLNA_MODEL_NUMBER" "Model number the daemon will report to clients in its XML description"
    printvar "MINIDLNA_DB_DIR" "set this if you would like to specify the directory where you want MiniDLNA to store its database and album art cache"
    printvar "MINIDLNA_ROOT_CONTAINER" "use different container as root of the tree"
    printvar "MINIDLNA_SORT_CRITERIA" "always force SortCriteria to this value"
    #---------------------------------------------------------------------------
    printgroup "LOG configuration"
    # ------------------------------------------------------------------------
    printvar "MINIDLNA_LOG_DEBUG" "yes or no"
    printvar "MINIDLNA_LOG_INTERVAL" "daily|weekly|monthly"
    printvar "MINIDLNA_LOG_COUNT" "Anzah der Logdateien"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{

# create file check.d

    printgpl -check ${packageName} "$(date "+%Y-%m-%d")" "Baeumer" >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG

# Variable                OPT_VARIABLE      VARIABLE_N          VALUE
START_MINIDLNA            -                 -                   YESNO
MINIDLNA_PORT             START_MINIDLNA    -                   PORT
MINIDLNA_MAX_CONNECTION   START_MINIDLNA    -                   NUMERIC
MINIDLNA_USER             START_MINIDLNA    -                   MINIDLNA_USER
MINIDLNA_NIC_N            START_MINIDLNA    -                   NUMERIC
MINIDLNA_NIC_%            START_MINIDLNA    MINIDLNA_NIC_N      MINIDLNA_NET_DEV
MINIDLNA_MERGE_MEDIA_DIR  START_MINIDLNA    -                   YESNO
MINIDLNA_MEDIA_N          START_MINIDLNA    -                   NUMERIC
MINIDLNA_MEDIA_%_DIR      START_MINIDLNA    MINIDLNA_MEDIA_N    ABS_PATH
MINIDLNA_MEDIA_%_CONTENT  START_MINIDLNA    MINIDLNA_MEDIA_N    MINIDLNA_CONTENT
MINIDLNA_READ_PLAYLIST    START_MINIDLNA    -                   YESNO
MINIDLNA_WIDE_LINKS       START_MINIDLNA    -                   YESNO
MINIDLNA_NAME             START_MINIDLNA    -                   MINIDLNA_WEBNAME
MINIDLNA_ALBUM_NAMES      START_MINIDLNA    -                   NOTEMPTY
MINIDLNA_INOTIFY          START_MINIDLNA    -                   YESNO
MINIDLNA_ENABLE_TIVO      START_MINIDLNA    -                   YESNO
MINIDLNA_STRICT_DLNA      START_MINIDLNA    -                   YESNO
MINIDLNA_WEB_URL          START_MINIDLNA    -                   NONE
MINIDLNA_NTFY_INTERVAL    START_MINIDLNA    -                   NUMERIC
MINIDLNA_SERIAL           START_MINIDLNA    -                   NUMERIC
MINIDLNA_MODEL_NUMBER     START_MINIDLNA    -                   NUMERIC
MINIDLNA_ROOT_CONTAINER   START_MINIDLNA    -                   MINIDLNA_ROOT_CONTAINER
MINIDLNA_DB_DIR           START_MINIDLNA    -                   NONE
MINIDLNA_SORT_CRITERIA    START_MINIDLNA    -                   NONE
MINIDLNA_LOG_DEBUG        START_MINIDLNA    -                   YESNO
MINIDLNA_LOG_INTERVAL     START_MINIDLNA    -                   LOG_INTERVAL
MINIDLNA_LOG_COUNT        START_MINIDLNA    -                   NUMERIC

EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/${packageName}
chown root /etc/check.d/${packageName}

printgpl --check_exp ${packageName} "$(date "+%Y-%m-%d")" "Baeumer" >/etc/check.d/${packageName}.exp
cat >> /etc/check.d/${packageName}.exp <<EOFG

MINIDLNA_NUMERIC    = '1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|19|19|20'
                    : 'only fsfs or bdb are allowed'

MINIDLNA_CONTENT    = 'All|Audio|Video|Photo'
                    : 'only All, Audio, Video, Photo are allwod'

MINIDLNA_WEBNAME    = '[[:alnum:]](_|-?[[:alnum:]])*'
                    : 'wrong name, only letters, numbers, minus signs
                       and underscores are allowed;
                       no leading or trailing minus signs'

MINIDLNA_ROOT_CONTAINER = 'use standard container|Browse Directory|Music|Video|Pictures'
                        : 'only use standard container,Browse Directory,Music,Video,Pictures'

MINIDLNA_NET_DEV = "(RE:NOBLANK)"
                 : "only use available network devices"

MINIDLNA_USER = '(RE:NOBLANK)' : 'value must be a valid username'
EOFG

# Set rights for check.exp file
chmod 0600 /etc/check.d/${packageName}.exp
chown root /etc/check.d/${packageName}.exp

# printgpl --check_ext ${packageName} "$(date "+%Y-%m-%d")" "Baeumer" >/etc/check.d/${packageName}.ext
# cat >> /etc/check.d/${packageName}.ext <<EOFG
#
# EOFG

# Set rights for check.ext file
# chmod 0600 /etc/check.d/${packageName}.ext
# chown root /etc/check.d/${packageName}.ext
# create file check.ext - not used yet

}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------

# Write default config file
makeConfigFile /etc/default.d/${packageName}

# Update from old version
renameOldVariables

# Write new config file
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
makeCheckFile

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
