#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/minidlna.sh - MINIDLNA configuration
#
# Creation   : 2010-01-02 jk
# Last update: $Id: minidlna.sh 3266 2024-04-17 19:01:35Z root $
#
# Copyright (c) 2011 Peter Baeumer, <peter(at)baeumer(dot)duckdns(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/minidlna-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Config Dateien
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# include config
. /etc/config.d/minidlna
. /etc/minidlna/minidlna.conf

# set package name
packageName=minidlna

minidlnaBin=/usr/sbin/minidlnad
minidlnaConf=/etc/minidlna/minidlna.conf
minidlnaLog=/var/log/upnp-av.log

###----------------------------------------------------------------------------
# Functions
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# create start file
#------------------------------------------------------------------------------

checkRequiredRecreateFilesdb ()
{
    if [ "${MINIDLNA_READ_PLAYLIST}" == "yes" ]; then
        plist=""
    else
        plist="-L"
    fi

    grep '\-L' /etc/minidlna/minidlna-start.sh > /dev/null 2>&1
    if [ $? == '0' ]; then
        opt_L="-L"
    else
        opt_L=""
    fi

    [ "${opt_L}" == "${plist}" ] || rm -vf /var/lib/minidlna/files.db

    grep merge_media_dirs /etc/minidlna/minidlna.conf > /dev/null 2>&1
    if [ $? == '0' ]; then
        [ "$merge_media_dirs" == "$MINIDLNA_MERGE_MEDIA_DIR" ] || rm -vf /var/lib/minidlna/files.db
    fi
}

#------------------------------------------------------------------------------
# create logrotate file
#------------------------------------------------------------------------------
createLogrotateFile ()
{
    LOGROTATEFILE="/etc/logrotate.d/${packageName}"
    (
        echo "#-----------------------------------------------------------------------------"
        echo "# ${LOGROTATEFILE} file generated by $0 "
        echo "# ${LOGROTATEFILE}"
        echo "# Do not change this file"
        echo "# Creation date: `date` "
        echo "#-----------------------------------------------------------------------------"
        echo ""
        echo "/var/log/minidlna.log /var/log/upnp-av.log {"
        echo "  $MINIDLNA_LOG_INTERVAL"
        echo "  missingok"
        echo "  rotate $MINIDLNA_LOG_COUNT"
        echo "  compress"
        echo "  delaycompress"
        echo "  notifempty"
        echo "  postrotate"
        echo "  /usr/sbin/service --quiet restart minidlna"
        echo "  endscript"
        echo "}"
    ) > ${LOGROTATEFILE}
}

#------------------------------------------------------------------------------
# create configuration file
#------------------------------------------------------------------------------
createConfigurationFile ()
{
    # Write information to configuration file
    CONFIGFILE="/etc/${packageName}/${packageName}.conf"
    (
        echo "#! /bin/sh"
        echo "#-----------------------------------------------------------------------------"
        echo "# ${STARTFILE} file generated by $0 "
        echo "# $CONFIGFILE    "
        echo "# Do not change this file; instead change /etc/config.d/${packageName}"
        echo "# Creation date: "$(date "+%Y-%m-%d")" "
        echo "#-----------------------------------------------------------------------------"
        echo "#"
        echo "port=$MINIDLNA_PORT"
        if [ "$MINIDLNA_MAX_CONNECTION" -gt "0" ]; then
            echo "max_connections=$MINIDLNA_MAX_CONNECTION"
        fi

    idx=1
    MINIDLNA_NIC=""
    separator=''
    nic_count=$MINIDLNA_NIC_N
    while [ "$idx" -le $nic_count ]
    do
        eval nic_name='$MINIDLNA_NIC_'${idx}
        if [ "$nic_name'" != "NONE" ]
        then
            MINIDLNA_NIC=${MINIDLNA_NIC}${separator}${nic_name}
            separator=','
            idx=`/usr/bin/expr $idx + 1`
        fi
    done
    echo "network_interface=$MINIDLNA_NIC"
    echo "merge_media_dirs=$MINIDLNA_MERGE_MEDIA_DIR"

        # check amount of media directories
        if [ $MINIDLNA_MEDIA_N -eq 0 ]
            then
                    imax=1
            else
                    imax=$MINIDLNA_MEDIA_N
            fi

        # write each media directory into config file
            idx=1
            while [ "$idx" -le $imax ]
            do
                eval pDir='$MINIDLNA_MEDIA_'$idx'_DIR'
                eval pContent='$MINIDLNA_MEDIA_'$idx'_CONTENT'

                case ${pContent}
                in
                    "Audio")
                        pCon="A,"
                    ;;
                    "Video")
                        pCon="V,"
                    ;;
                    "Photo")
                        pCon="P,"
                    ;;
                    *)
                        pCon=""
                    ;;
                esac
            echo "media_dir=$pCon$pDir"
            idx=`/usr/bin/expr $idx + 1`
            done

        echo "friendly_name=$MINIDLNA_NAME"
        echo "db_dir=$MINIDLNA_DB_DIR"
        echo "album_art_names=$MINIDLNA_ALBUM_NAMES"
        echo "inotify=$MINIDLNA_INOTIFY"
        echo "enable_tivo=$MINIDLNA_ENABLE_TIVO"
        echo "strict_dlna=$MINIDLNA_STRICT_DLNA"
        echo "presentation_url=$MINIDLNA_WEB_URL"
        echo "notify_interval=$MINIDLNA_NTFY_INTERVAL"
        echo "serial=$MINIDLNA_SERIAL"
        echo "model_number=$MINIDLNA_MODEL_NUMBER"

        case $MINIDLNA_ROOT_CONTAINER
            in
            "use standard container")
                echo "root_container=."
            ;;
            "Browse Directory")
               echo "root_container=B"
            ;;
            "Music")
                echo "root_container=M"
            ;;
            "Video")
                echo "root_container=V"
            ;;
            "Pictures")
                echo "root_container=P"
            ;;
            *)
            ;;
        esac

        if [ "$MINIDLNA_SORT_CRITERIA" != "" ]; then
        echo "force_sort_criteria=$MINIDLNA_SORT_CRITERIA"
        fi 

        echo "log_dir=/var/log/"
        echo "wide_links=$MINIDLNA_WIDE_LINKS"
        echo ""
    ) > ${CONFIGFILE}
    chmod 0644 ${CONFIGFILE}
}

createStartFile ()
{
     if [ "${MINIDLNA_READ_PLAYLIST}" == "yes" ]; then
            plist=""
        else
            plist="-L"
        fi

        if [ "${MINIDLNA_USER}" == "root" ]; then
            user=""
        else
            user="-u ${MINIDLNA_USER}"
            sudo -u ${MINIDLNA_USER} [ -w ${MINIDLNA_DB_DIR}/files.db ]
            if [ $? != '0' ] ; then
                [ -f ${MINIDLNA_DB_DIR}/files.db  ] && chown -R ${MINIDLNA_USER}:root ${MINIDLNA_DB_DIR}/files.db  > /dev/null 2>&1
                [ -d ${MINIDLNA_DB_DIR}/art_cache ] && chown -R ${MINIDLNA_USER}:root ${MINIDLNA_DB_DIR}/art_cache > /dev/null 2>&1
            fi
        fi

        if [ "${MINIDLNA_LOG_DEBUG}" = 'yes' ]; then
            log_debug="-d"
            background='&'
        else
            log_debug=""
            background=''
        fi
        echo "#! /bin/bash" > /etc/minidlna/minidlna-start.sh
        echo "[ \"\$1\" != \"\" ] && rescan=\"-R\"" >> /etc/minidlna/minidlna-start.sh
        echo "${minidlnaBin} \${rescan} ${user} ${log_debug} ${plist} -P /var/run/minidlna.pid -f ${minidlnaConf} > /var/log/upnp-av.log 2>&1 ${background}" >> /etc/minidlna/minidlna-start.sh
        echo "" >> /etc/minidlna/minidlna-start.sh
        chmod 0755 /etc/minidlna/minidlna-start.sh
}
#------------------------------------------------------------------------------
# Functions end
###----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
createConfigurationFile
checkRequiredRecreateFilesdb
createStartFile
createLogrotateFile

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------

